@@ -5,7 +5,7 @@
 # SearchEnginesHashLib.
 # An entry if known in SearchEnginesKnownUrl is also welcome.
 #------------------------------------------------------------------------------
-# $Revision: 1.41 $ - $Author: eldy $ - $Date: 2006/11/15 22:30:15 $
+# $Revision: 1.43 $ - $Author: eldy $ - $Date: 2007/06/06 17:14:21 $
 
 # 2005-08-19 Sean Carlos http://www.antezeta.com/awstats.html
 #            added minor italian search engines
@@ -194,6 +194,7 @@
 # Minor international search engines
 '4\-counter\.com',
 'att\.net',
+'bungeebonesdotcom',
 'northernlight\.',
 'hotbot\.',
 'kvasir\.',
@@ -397,6 +398,7 @@
 # Minor international search engines
 '4\-counter\.com','google4counter',
 'att\.net','att',
+'bungeebonesdotcom','bungeebonesdotcom',
 'northernlight\.','northernlight',
 'hotbot\.','hotbot',
 'kvasir\.','kvasir',
@@ -659,6 +661,7 @@
 # Minor international search engines
 'google4counter','(p|q|as_p|as_q)=',
 'att','qry=',
+'bungeebonesdotcom','query=',
 'go','qt=',
 'askde','(ask|q)=', # break out Ask country specific engines.
 'askes','(ask|q)=',
@@ -877,6 +880,7 @@
 # Minor international search engines
 'google4counter','<a href="http://www.4-counter.com/" title="Search Engine Home Page [new window]" target="_blank">4-counter (Google)</a>',
 'att','<a href="http://www.att.net/" title="Search Engine Home Page [new window]" target="_blank">AT&T search (powered by Google)</a>',
+'bungeebonesdotcom','<a href="http://BungeeBones.com/search.php/" title="Search Engine Home Page [new window]" target="_blank">BungeeBones</a>',
 'go','Go.com',
 'askde','<a href="http://de.ask.com/" title="Search Engine Home Page [new window]" target="_blank">Ask Deutschland</a>',
 'askes','<a href="http://es.ask.com/" title="Search Engine Home Page [new window]" target="_blank">Ask Espa&ntilde;a</a>', # break out Ask country specific engines.
@@ -916,10 +920,10 @@
 'sphere','<a href="http://www.sphere.com/" title="Search Engine Home Page [new window]" target="_blank">Sphere (Blog)</a>',
 'ledix','<a href="http://www.ledix.net/" title="Search Engine Home Page [new window]" target="_blank">Ledix</a>',
 'shawca','<a href="http://start.shaw.ca/" title="Search Engine Home Page [new window]" target="_blank">Shaw.ca</a>',
-'searchalot','<http://www.searchalot.com/" title="Search Engine Home Page [new window]" target="_blank">Searchalot</a>',
-'copernic','<http://www.copernic.com/" title="Search Engine Home Page [new window]" target="_blank">Copernic</a>',
-'avantfind','<http://www.avantfind.com/" title="Search Engine Home Page [new window]" target="_blank">Avantfind</a>',
-'steadysearch','<http://www.avantfind.com/" title="Search Engine Home Page [new window]" target="_blank">Avantfind</a>',
+'searchalot','<a href="http://www.searchalot.com/" title="Search Engine Home Page [new window]" target="_blank">Searchalot</a>',
+'copernic','<a href="http://www.copernic.com/" title="Search Engine Home Page [new window]" target="_blank">Copernic</a>',
+'avantfind','<a href="http://www.avantfind.com/" title="Search Engine Home Page [new window]" target="_blank">Avantfind</a>',
+'steadysearch','<a href="http://www.avantfind.com/" title="Search Engine Home Page [new window]" target="_blank">Avantfind</a>',
 # Chello Portals
 'chelloat','<a href="http://www.chello.at/" title="Search Engine Home Page [new window]" target="_blank">Chello Austria</a>',
 'chellobe','<a href="http://www.chello.be/" title="Search Engine Home Page [new window]" target="_blank">Chello Belgium</a>',
@@ -1078,4 +1082,4 @@
 #}
 #print @SearchEnginesSearchIDOrder_list1." ".@SearchEnginesSearchIDOrder_list2." ".@SearchEnginesSearchIDOrder_listgen;
 
-1;
+1;
\ No newline at end of file
