@@ -5,15 +5,24 @@
 # from a Geographical database (US and Canada).
 # Need the licensed region database from Maxmind.
 #-----------------------------------------------------------------------------
-# Perl Required Modules: Geo::IP (Geo::IP::PurePerl is not yet supported)
+# Perl Required Modules: Geo::IP or Geo::IP::PurePerl
 #-----------------------------------------------------------------------------
-# $Revision: 1.7 $ - $Author: eldy $ - $Date: 2005/12/14 23:44:33 $
+# $Revision: 1.12 $ - $Author: eldy $ - $Date: 2006/05/06 02:54:48 $
 
 
 # <-----
 # ENTER HERE THE USE COMMAND FOR ALL REQUIRED PERL MODULES
-if (!eval ('require "Geo/IP.pm";')) 	{
-    return $@?"Error: $@":"Error: Need Perl module Geo::IP (Geo::IP::PurePerl is not yet supported)";
+use vars qw/ $type /;
+$type='geoip';
+if (!eval ('require "Geo/IP.pm";')) {
+	$error1=$@;
+	$type='geoippureperl';
+	if (!eval ('require "Geo/IP/PurePerl.pm";')) {
+		$error2=$@;
+		$ret=($error1||$error2)?"Error:\n$error1$error2":"";
+		$ret.="Error: Need Perl module Geo::IP or Geo::IP::PurePerl";
+		return $ret;
+	}
 }
 # ----->
 use strict;no strict "refs";
@@ -26,13 +35,14 @@ use strict;no strict "refs";
 # <-----
 # ENTER HERE THE MINIMUM AWSTATS VERSION REQUIRED BY YOUR PLUGIN
 # AND THE NAME OF ALL FUNCTIONS THE PLUGIN MANAGE.
-my $PluginNeedAWStatsVersion="6.2";
+my $PluginNeedAWStatsVersion="6.5";
 my $PluginHooksFunctions="AddHTMLMenuLink AddHTMLGraph ShowInfoHost SectionInitHashArray SectionProcessIp SectionProcessHostname SectionReadHistory SectionWriteHistory";
 # ----->
 
 # <-----
 # IF YOUR PLUGIN NEED GLOBAL VARIABLES, THEY MUST BE DECLARED HERE.
 use vars qw/
+%TmpDomainLookup
 $geoip_region_maxmind
 %_region_p
 %_region_h
@@ -140,15 +150,25 @@ sub Init_geoip_region_maxmind {
 	# <-----
 	# ENTER HERE CODE TO DO INIT PLUGIN ACTIONS
 	debug(" Plugin geoip_region_maxmind: InitParams=$InitParams",1);
-#    if ($UpdateStats) {
-    	my ($mode,$datafile)=split(/\s+/,$InitParams,2);
-    	if (! $datafile) { $datafile="GeoIPRegion.dat"; }
-    	if ($mode eq '' || $mode eq 'GEOIP_MEMORY_CACHE')  { $mode=Geo::IP::GEOIP_MEMORY_CACHE(); }
-    	else { $mode=Geo::IP::GEOIP_STANDARD(); }
-    	debug(" Plugin geoip_region_maxmind: GeoIP initialized in mode $mode",1);
-        $geoip_region_maxmind = Geo::IP->open($datafile, $mode);
-#    }
-	# ----->
+   	my ($mode,$datafile)=split(/\s+/,$InitParams,2);
+   	if (! $datafile) { $datafile="GeoIPRegion.dat"; }
+	if ($type eq 'geoippureperl') {
+		if ($mode eq '' || $mode eq 'GEOIP_MEMORY_CACHE')  { $mode=Geo::IP::PurePerl::GEOIP_MEMORY_CACHE(); }
+		else { $mode=Geo::IP::PurePerl::GEOIP_STANDARD(); }
+	} else {
+		if ($mode eq '' || $mode eq 'GEOIP_MEMORY_CACHE')  { $mode=Geo::IP::GEOIP_MEMORY_CACHE(); }
+		else { $mode=Geo::IP::GEOIP_STANDARD(); }
+	}
+	%TmpDomainLookup=();
+	debug(" Plugin geoip_region_maxmind: GeoIP initialized type=$type mode=$mode",1);
+	if ($type eq 'geoippureperl') {
+		$geoip_region_maxmind = Geo::IP::PurePerl->open($datafile, $mode);
+	} else {
+		$geoip_region_maxmind = Geo::IP->open($datafile, $mode);
+	}
+# Fails with some geoip versions
+# 	debug(" Plugin geoip_region_maxmind: GeoIP initialized database_info=".$geoip_region_maxmind->database_info());
+ 	# ----->
 
 	return ($checkversion?$checkversion:"$PluginHooksFunctions");
 }
@@ -166,7 +186,7 @@ sub AddHTMLMenuLink_geoip_region_maxmind {
 	# <-----
 	if ($Debug) { debug(" Plugin geoip_region_maxmind: AddHTMLMenuLink"); }
     if ($categ eq 'who') {
-        $menu->{'plugin_geoip_region_maxmind'}=2.1;               # Pos
+        $menu->{'plugin_geoip_region_maxmind'}=2.1;             # Pos
         $menulink->{'plugin_geoip_region_maxmind'}=2;           # Type of link
         $menutext->{'plugin_geoip_region_maxmind'}="Regions";   # Text
     }
@@ -269,6 +289,52 @@ sub AddHTMLGraph_geoip_region_maxmind {
 }
 
 
+#-----------------------------------------------------------------------------
+# PLUGIN FUNCTION: GetCountryCodeByAddr_pluginname
+# UNIQUE: YES (Only one plugin using this function can be loaded)
+# GetCountryCodeByAddr is called to translate an ip into a country code in lower case.
+#-----------------------------------------------------------------------------
+# Rem: Not used
+sub GetCountryCodeByAddr_geoip_region_maxmind {
+    my $param="$_[0]";
+	# <-----
+	my $res=$TmpDomainLookup{$param}||'';
+	if (! $res) {
+    	my ($res1,$res2,$countryregion)=();
+    	($res1,$res2)=$geoip_region_maxmind->region_by_name($param) if $geoip_region_maxmind;
+    	$res=lc($res1) || 'unknown';
+		$TmpDomainLookup{$param}=$res;
+    	if ($Debug) { debug("  Plugin geoip_region_maxmind: GetCountryCodeByAddr for $param: [$res]",5); }
+	}
+	elsif ($Debug) { debug("  Plugin geoip_region_maxmind: GetCountryCodeByAddr for $param: Already resolved to [$res]",5); }
+	# ----->
+	return $res;
+}
+
+
+#-----------------------------------------------------------------------------
+# PLUGIN FUNCTION: GetCountryCodeByName_pluginname
+# UNIQUE: YES (Only one plugin using this function can be loaded)
+# GetCountryCodeByName is called to translate a host name into a country code in lower case.
+#-----------------------------------------------------------------------------
+# Rem: Not used
+sub GetCountryCodeByName_geoip_region_maxmind {
+    my $param="$_[0]";
+	# <-----
+	my $res=$TmpDomainLookup{$param}||'';
+	if (! $res) {
+    	my ($res1,$res2,$countryregion)=();
+    	($res1,$res2)=$geoip_region_maxmind->region_by_name($param) if $geoip_region_maxmind;
+    	$res=lc($res1) || 'unknown';
+		$TmpDomainLookup{$param}=$res;
+    	if ($Debug) { debug("  Plugin geoip_region_maxmind: GetCountryCodeByName for $param: [$res]",5); }
+	}
+	elsif ($Debug) { debug("  Plugin geoip_region_maxmind: GetCountryCodeByName for $param: Already resolved to [$res]",5); }
+	# ----->
+	return $res;
+}
+
+
 #-----------------------------------------------------------------------------
 # PLUGIN FUNCTION: ShowInfoHost_pluginname
 # UNIQUE: NO (Several plugins using this function can be loaded)
@@ -329,6 +395,7 @@ sub ShowInfoHost_geoip_region_maxmind {
                 }
             }
             else {
+            	# Show region
                 if ($res1 =~ /\w\w/ && $res2 =~ /\w\w/) {
                     print $region{lc($res1)}{uc($res2)};
                 }
@@ -354,6 +421,7 @@ sub ShowInfoHost_geoip_region_maxmind {
                 }
             }
             else {
+                # Show region
                 if ($res1 =~ /\w\w/ && $res2 =~ /\w\w/) {
                     print $region{lc($res1)}{uc($res2)};
                 }
@@ -375,7 +443,7 @@ sub ShowInfoHost_geoip_region_maxmind {
 # UNIQUE: NO (Several plugins using this function can be loaded)
 #-----------------------------------------------------------------------------
 sub SectionInitHashArray_geoip_region_maxmind {
-    my $param="$_[0]";
+#    my $param="$_[0]";
 	# <-----
 	if ($Debug) { debug(" Plugin geoip_region_maxmind: Init_HashArray"); }
 	%_region_p = %_region_h = %_region_k = %_region_l =();
@@ -412,7 +480,7 @@ sub SectionProcessHostname_geoip_region_maxmind {
 	# <-----
 	my ($res1,$res2,$countryregion)=();
 	($res1,$res2)=$geoip_region_maxmind->region_by_name($param) if $geoip_region_maxmind;
-	if ($Debug) { debug("  Plugin geoip_region_maxmind: GetRegionByName for $param: [{$res1}_{$res2}]",5); }
+	if ($Debug) { debug("  Plugin geoip_region_maxmind: GetRegionByName for $param: [${res1}_${res2}]",5); }
     if ($res2 =~ /\w\w/) { $countryregion=lc("${res1}_${res2}"); }
     else { $countryregion='unknown'; }
 #	if ($PageBool) { $_region_p{$countryregion}++; }
